==> log_analyzer_mcp-0.1.3.tar.gz: log_analyzer_mcp-0.1.3/docs/README.md <==
# Log Analyzer MCP Documentation

Welcome to the documentation for **Log Analyzer MCP**, a powerful Python-based toolkit for log analysis, offering both a Command-Line Interface (CLI) and a Model-Context-Protocol (MCP) server.

This documentation provides guides for users, integrators, and developers.

## Key Documentation Sections

- **[Getting Started Guide](./getting_started.md)**
  - Learn how to install and use the `loganalyzer` CLI.
  - Understand how to integrate the MCP server with client applications like Cursor.

- **[Developer Guide](./developer_guide.md)**
  - Detailed instructions for setting up the development environment, building the project, running tests, managing MCP server configurations for development, and release procedures.

- **[Refactoring Plans](./refactoring/README.md)**
  - Technical details and status of ongoing and past refactoring efforts for the project.
    - [Current Plan: Refactoring Plan v2](./refactoring/log_analyzer_refactoring_v2.md)

- **[Project Rules and Guidelines](./rules/README.md)**
  - Information on coding standards, Markdown linting, Python development practices, and GitHub workflows used in this project.

- **(Upcoming) Configuration Guide**
  - Will provide a detailed explanation of all `.env` and environment variable settings for configuring the Log Analyzer.

- **(Upcoming) CLI Usage Guide**
  - Will offer a comprehensive guide to all `loganalyzer` commands, options, and usage patterns.

## Project Overview

Log Analyzer MCP aims to:

- Simplify the analysis of complex log files.
- Provide flexible searching and filtering capabilities.
- Integrate seamlessly into developer workflows via its CLI and MCP server.

For a higher-level overview of the project, its unique selling points, and quick installation for MCP integration, please see the main [Project README.md](../README.md).

## Contributing

If you're interested in contributing to the project, please start by reading the [Developer Guide](./developer_guide.md) and the [CONTRIBUTING.md](../CONTRIBUTING.md) file in the project root.

## License

Log Analyzer MCP is licensed under the MIT License with Commons Clause. See the [LICENSE.md](../LICENSE.md) file in the project root for details.

==> log_analyzer_mcp-0.1.6.tar.gz: log_analyzer_mcp-0.1.6/docs/README.md <==
# Log Analyzer MCP Documentation

Welcome to the documentation for **Log Analyzer MCP**, a powerful Python-based toolkit for log analysis, offering both a Command-Line Interface (CLI) and a Model-Context-Protocol (MCP) server.

This documentation provides guides for users, integrators, and developers.

## Key Documentation Sections

- **[API Reference](./api_reference.md):** Detailed reference for MCP server tools and CLI commands.
- **[Getting Started Guide](./getting_started.md)**
  - Learn how to install and use the `log-analyzer` CLI.
  - Understand how to integrate the MCP server with client applications like Cursor.

- **[Developer Guide](./developer_guide.md)**
  - Detailed instructions for setting up the development environment, building the project, running tests, managing MCP server configurations for development, and release procedures.

- **[Refactoring Plans](./refactoring/README.md)**
  - Technical details and status of ongoing and past refactoring efforts for the project.
    - [Current Plan: Refactoring Plan v2](./refactoring/log_analyzer_refactoring_v2.md)

- **[Project Rules and Guidelines](./rules/README.md)**
  - Information on coding standards, Markdown linting, Python development practices, and GitHub workflows used in this project.

- **(Upcoming) Configuration Guide**
  - Will provide a detailed explanation of all `.env` and environment variable settings for configuring the Log Analyzer.

- **(Upcoming) CLI Usage Guide**
  - Will offer a comprehensive guide to all `log-analyzer` commands, options, and usage patterns.

## Project Overview

Log Analyzer MCP aims to:

- Simplify the analysis of complex log files.
- Provide flexible searching and filtering capabilities.
- Integrate seamlessly into developer workflows via its CLI and MCP server.

For a higher-level overview of the project, its unique selling points, and quick installation for MCP integration, please see the main [Project README.md](../README.md).

## Contributing

If you're interested in contributing to the project, please start by reading the [Developer Guide](./developer_guide.md) and the [CONTRIBUTING.md](../CONTRIBUTING.md) file in the project root.

## License

Log Analyzer MCP is licensed under the MIT License with Commons Clause. See the [LICENSE.md](../LICENSE.md) file in the project root for details.
